<?php

namespace itguild\forms\app\controllers;

use itguild\forms\app\core\BaseController;

use itguild\forms\app\models\FormModel;
use itguild\forms\app\models\FormResModel;
use itguild\forms\app\models\User;
use itguild\forms\debug\Debug;
use itguild\forms\Form;
use itguild\forms\JsonForm;
use itguild\forms\widgets\TableJsonWidget;
use Twig\TwigFunction;


class FormController extends BaseController
{
    public function indexAction($id): void
    {
        // Инициализируем пустые массивы
        $meta = [];
        $formArr = [];
        $formFieldsArr = [];

        // Получение формы из БД и обработка мета данных формы
        $form = FormModel::find($id);
        if ($form->params) {
            $meta = array_merge($meta, json_decode($form->params, true));
        }
        $meta['action'] = "/form-save/" . $form->id;
        $meta['method'] = "POST";
        $formArr['meta'] = $meta;

        // Обработка полей формы
        $fields = $form->fields;
        foreach ($fields as $field) {
            $options = [];
            $fieldArr = [];
            if ($field->inputValue) {
                foreach ($field->inputValue as $value) {
                    $options[$value['id']] = $value['value'];
                }
            }

            if ($field->params) {
                $fieldArr = array_merge($fieldArr, json_decode($field->params, true));
            }
            $fieldArr['type'] = $field->inputType['type'] ? $field->inputType['type'] : "textInput";
            $fieldArr['options'] = $options;
            $formArr['data'][] = $fieldArr;
        }

        $formArr['data'][] = ['type' => "button", 'typeInput' => "submit", "value" => "Отправить", "name" => "", "class" => "btn btn-primary"];

        //Debug::dd($fields);

        $this->view->addFunction(new TwigFunction("create_form", function () use ($formArr) {
            $form = new JsonForm(json_encode($formArr));
            $form->convertHTML();
            $form->render();
        }));

        echo $this->view->render('form/form.html.twig', ['title' => $form->title]);

    }

    public function saveAction($id): void
    {
        $form = FormResModel::Create(['form_id' => $id, 'data' => json_encode($_POST),]);
    }

    public function createFormAction()
    {
        $form = Form::Create(['title' => "dsds", 'status' => 1, 'params' => "",]);
    }

    public function result($id)
    {
            $meta = [];
            $data = [];
            $tableArr = [];

            $table = FormResModel::where("form_id", $id)->get();
            foreach ($table as $key => $item){

                $data[] = json_decode($item->data, true);

            }

            $meta['title'] = "Form ID: " . $id;
            $meta['columns'] = ["email" => "Email", "description" => "Описание 1", "description2" => "Описание 2"];
            $meta['params'] = ["class" => "table table-bordered", "border" => "1"];


            $tableArr["meta"] = $meta;
            $tableArr["data"] = $data;
            $tableRes = json_encode($tableArr);
            
            $this->view->addFunction(new TwigFunction("create_table", function () use ($tableRes) {

                $table = new TableJsonWidget($tableRes);
                $table->create();
                $table->render();

            }));

            echo $this->view->render('form/result.html.twig', ['title' => $tableArr['meta']["title"]]);
    }

}